==> flowFlowJo_1.2.0.tar.gz: flowFlowJo/R/createFlowReport.R <==

setMethod("createFlowReport",
          signature(summaryList = "fcsSummaryList"), 
          definition = function(summaryList, 
                                factorsFrame=NULL, 
                                populations=NULL,
                                channels=NULL, 
                                includeKeywords=TRUE,
                                joinFactors=c("FCSFilename", "FlowJoWorkspace"),
                                dropJoinFactors=TRUE) {
                                     
 
  # Define the column headers and setup output format
  resultsFrame <- data.frame(stringsAsFactors=FALSE);
  keywords     <- names(summaryList@summaries[[1]]@textList);
  colHeaders   <- c("Row", "Column", "CellType", "Measure", "Value", "FCSname");
  if (includeKeywords)             { colHeaders = c(colHeaders, keywords); }
  if (is.data.frame(factorsFrame)) { colHeaders = c(colHeaders, names(factorsFrame)); } 

  # Now work through every FCS file and its related data
  count        <- 1;
  cat("\n   Working through the summaryList information");
  for (i in 1:length(summaryList@summaries)) {
    cat(".");
    aFileSummary    <- summaryList@summaries[[i]];
    flowJoWorkspace <- aFileSummary@FlowJoWorkspace;
    if (is.null(populations)) { 
      tempPops = rownames(aFileSummary@popMat); 
    } else {
      tempPops = populations;
    }
    
    for (j in 1:length(tempPops)) {
      aPop = tempPops[j];
      if (is.null(channels)) { 
        tempChannels = colnames(aFileSummary@popMat); 
      } else {
        tempChannels = channels;
      }
      
      for (k in 1:length(tempChannels)) {
        aMeasure = tempChannels[k];
#print(paste("Gold", i, j, k, count, aPop, aMeasure));
#print(summaryList[[i]]$popMat);
        # Assebmle basic MFI information (and Time and Counts?)
        aLine = list(Row      = aFileSummary@wellId$RowSymbol,
                     Column   = aFileSummary@wellId$Column,
                     CellType = aPop,
                     Measure  = aMeasure,
                     Value    = aFileSummary@popMat[j,k],
                     FCSfile  = aFileSummary@fcsName);  
#print("Electrum");        
        # Tack on keywords in a terribly de-normalized way
        if (includeKeywords) {
          if (identical(names(aFileSummary@textList), keywords)) {
#print("Including keywords...");
            aLine = append(aLine, aFileSummary@textList);
          } else {  
            errorMsg = paste("Urrk!  Different elements of your summaryList seem",
                             "to have different keywords associated with them.  ",
                             "take a look a the 'textList' section of the first ",
                             "assembly vs. that of assembly ", i, sep=' ');
            stop(errorMsg);
          }
        }
        
        # Tack on other factors (match by FlowJoWorkspace and fcsName
        if (is.data.frame(factorsFrame)) {
#          print("Adding factorsFrame info...");
          index = (factorsFrame$FCSFilename == aFileSummary@FCSFilename) &
                  (factorsFrame$FlowJoWorkspace == aFileSummary@FlowJoWorkspace);
          if (sum(index) != 1) { 
            errorMsg = paste("Hey, you are trying to join information from a dataframe",
                        "(factorsFrame), and information extracted from the FlowJoWorkspace",
                        "and related FCS files, but you have more (or less) than one match between",
                        "the files described in the two lists.  Look at lines ",
                        which(index), " in the factorsFrame.", sep=' ');
            stop(errorMsg);
          }
          extraInfo = as.character(as.matrix(factorsFrame[index,]));
          aLine     = append(aLine, extraInfo);
        }

#        print("Copper"); print(as.character(aLine)); print(colHeaders); cat("\n");
        names(aLine) <- colHeaders; 
        if (count == 1) {
          resultsFrame = as.data.frame(x=aLine, stringsAsFactors=FALSE);
        } else {
          resultsFrame = rbind(resultsFrame, unlist(aLine));
        }
         
        count = count + 1;      
      }    # move on to next channel
    }    # move on to next population
  }    # move on to the next FCS file
  
  # Typically these factors are included in the incoming factorsFrame only for
  # purpose of merging the data/lines coming from the summaryList and the 
  # factorsFrame.  Usually, these columns only make the output harder to read.
  if (dropJoinFactors) { 
    resultsFrame = resultsFrame[, !(names(resultsFrame) %in% joinFactors)];
  }
  
  # Certain columns are usually going to be numbers.  Convert them here:
  for (aCol in names(resultsFrame)) {
    test = as.numeric(resultsFrame[,aCol]);
#    print(paste(aCol, sum(is.na(test))));
    if (sum(is.na(test)) < 0.25 * nrow(resultsFrame)) {
      resultsFrame[,aCol] = test;
    }
  }
  
  cat("\n\n");         
  return(resultsFrame);
});

==> flowFlowJo_1.4.0.tar.gz: flowFlowJo/R/createFlowReport.R <==

setMethod("createFlowReport",
          signature(summaryList = "fcsSummaryList"), 
          definition = function(summaryList, 
                                factorsFrame=NULL, 
                                populations=NULL,
                                channels=NULL, 
                                includeKeywords=TRUE,
                                joinFactors=c("FCSFilename", "FlowJoWorkspace"),
                                dropJoinFactors=TRUE) {
                                     
 
  # Define the column headers and setup output format
  resultsFrame <- data.frame(stringsAsFactors=FALSE);
  keywords     <- names(summaryList@summaries[[1]]@textList);
  colHeaders   <- c("Row", "Column", "CellType", "Measure", "Value", "FCSname");
  if (includeKeywords)             { colHeaders = c(colHeaders, keywords); }
  if (is.data.frame(factorsFrame)) { colHeaders = c(colHeaders, names(factorsFrame)); } 

  # Now work through every FCS file and its related data
  count         <- 1;
  flowFileCount <- 0;
  cat("\nWorking through the summaryList information.  FCS files processed so far: \n");
  for (i in 1:length(summaryList@summaries)) {
#    cat(".");
    flowFileCount   <- flowFileCount + 1;
    if ((flowFileCount %% 30) == 0) {
       cat(flowFileCount); cat(" ");
    } 
    if ((flowFileCount %% 300) == 0) {  cat("\n") }

    # THE INCOMING SUMMARYLIST HAS ONE ITEM PER FCS FILE.   IT ALSO CONTAINS A LIST
    # OF ALL THE POSSIBLE POPULATIONS FOUND IN IT.
    aFileSummary    <- summaryList@summaries[[i]];
    flowJoWorkspace <- aFileSummary@FlowJoWorkspace;
    if (is.null(populations)) { 
      tempPops = rownames(aFileSummary@popMat); 
    } else {
      tempPops = populations;
    }
    
    for (j in 1:length(tempPops)) {
      aPop = tempPops[j];
      if (is.null(channels)) { 
        tempChannels = colnames(aFileSummary@popMat); 
      } else {
        tempChannels = channels;
      }
      
      for (k in 1:length(tempChannels)) {
        aMeasure = tempChannels[k];
#print(paste("Gold", i, j, k, count, aPop, aMeasure));
#print(summaryList[[i]]$popMat);
        # Assebmle basic MFI information (and Time and Counts?)
        
# SOMEWHERE AR0UND HERE I WOULD NEED TO UNPACK 
        aLine = list(Row      = aFileSummary@wellId$RowSymbol,
                     Column   = aFileSummary@wellId$Column,
                     CellType = aPop,
                     Measure  = aMeasure,
                     Value    = aFileSummary@popMat[j,k],
                     FCSfile  = aFileSummary@fcsName);  
#print("Electrum");        
        # Tack on keywords in a terribly de-normalized way
        if (includeKeywords) {
          if (identical(names(aFileSummary@textList), keywords)) {
#print("Including keywords...");
            aLine = append(aLine, aFileSummary@textList);
          } else {  
            errorMsg = paste("Urrk!  Different elements of your summaryList seem",
                             "to have different keywords associated with them.  ",
                             "take a look a the 'textList' section of the first ",
                             "assembly vs. that of assembly ", i, sep=' ');
            stop(errorMsg);
          }
        }
        
        # Tack on other factors (match by FlowJoWorkspace and fcsName
        if (is.data.frame(factorsFrame)) {
#          print("Adding factorsFrame info...");
          index = (factorsFrame$FCSFilename == aFileSummary@FCSFilename) &
                  (factorsFrame$FlowJoWorkspace == aFileSummary@FlowJoWorkspace);
          if (sum(index) != 1) { 
            errorMsg = paste("Hey, you are trying to join information from a dataframe",
                        "(factorsFrame), and information extracted from the FlowJoWorkspace",
                        "and related FCS files, but you have more (or less) than one match between",
                        "the files described in the two lists.  Look at lines ",
                        which(index), " in the factorsFrame.", sep=' ');
            stop(errorMsg);
          }
          extraInfo = as.character(as.matrix(factorsFrame[index,]));
          aLine     = append(aLine, extraInfo);
        }

#        print("Copper"); print(as.character(aLine)); print(colHeaders); cat("\n");
        names(aLine) <- colHeaders; 
        if (count == 1) {
          resultsFrame = as.data.frame(x=aLine, stringsAsFactors=FALSE);
        } else {
          resultsFrame = rbind(resultsFrame, unlist(aLine));
        }
         
        count = count + 1;      
      }    # move on to next channel
    }    # move on to next population
  }    # move on to the next FCS file
  
  # Typically these factors are included in the incoming factorsFrame only for
  # purpose of merging the data/lines coming from the summaryList and the 
  # factorsFrame.  Usually, these columns only make the output harder to read.
  if (dropJoinFactors) { 
    resultsFrame = resultsFrame[, !(names(resultsFrame) %in% joinFactors)];
  }
  
  # Certain columns are usually going to be numbers.  Convert them here:
  for (aCol in names(resultsFrame)) {
    test = is.finite(resultsFrame[,aCol]);
#    print(paste(aCol, sum(is.na(test))));
    if (sum(test) > 0.75 * nrow(resultsFrame)) {
      resultsFrame[,aCol] = as.numeric(resultsFrame[,aCol]);
    }
  }
  
  cat(" Done!\n\n");         
  return(resultsFrame);
});
